@@ -32,14 +32,14 @@ AdditionalDataValue = Dict[str, Any]
 @dataclass
 class Point(DataClassJsonMixin):
     """
-    座標
+    点の座標値
     """
 
     x: int
-    """"""
+    """X座標の値[ピクセル]"""
 
     y: int
-    """"""
+    """Y座標の値[ピクセル]"""
 
 
 @dataclass
@@ -47,20 +47,18 @@ class FullAnnotationDataClassification(DataClassJsonMixin):
     """ """
 
     type: str
-    """Classification"""
+    """`Classification` """
 
 
 @dataclass
 class FullAnnotationDataSegmentation(DataClassJsonMixin):
-    """
-    塗っていないところは rgba(0,0,0,0)、塗ったところは rgba(255,255,255,1) の PNGデータをBase64エンコードしたもの。
-    """
+    """ """
 
     data_uri: str
-    """"""
+    """塗りつぶし画像のパス"""
 
     type: str
-    """Segmentation"""
+    """`Segmentation` """
 
 
 @dataclass
@@ -68,17 +66,15 @@ class FullAnnotationDataSegmentationV2(DataClassJsonMixin):
     """ """
 
     data_uri: str
-    """"""
+    """塗りつぶし画像のパス"""
 
     type: str
-    """SegmentationV2"""
+    """`SegmentationV2` """
 
 
 @dataclass
 class FullAnnotationDataBoundingBox(DataClassJsonMixin):
-    """
-    annotation_type が bounding_boxの場合に、[左上頂点座標, 右下頂点座標]を {\"x\":int, \"y\":int} の形式で記述したもの。
-    """
+    """ """
 
     left_top: Point
     """"""
@@ -87,49 +83,43 @@ class FullAnnotationDataBoundingBox(DataClassJsonMixin):
     """"""
 
     type: str
-    """BoundingBox"""
+    """`BoundingBox` """
 
 
 @dataclass
 class FullAnnotationDataPoints(DataClassJsonMixin):
-    """
-    頂点座標 {\"x\":int, \"y\":int} の配列。  * annotation_type が polygon/polyline の場合: ポリゴン/ポリラインを構成する頂点の配列。
-    """
+    """ """
 
     points: List[Point]
-    """"""
+    """頂点の座標値"""
 
     type: str
-    """Points"""
+    """`Points` """
 
 
 @dataclass
 class FullAnnotationDataSinglePoint(DataClassJsonMixin):
-    """
-    annotation_type が pointの場合。
-    """
+    """ """
 
     point: Point
     """"""
 
     type: str
-    """SinglePoint。"""
+    """`SinglePoint` """
 
 
 @dataclass
 class FullAnnotationDataRange(DataClassJsonMixin):
-    """
-    annotation_type が rangeの場合に、[開始時間, 終了時間]を {\"begin\":number, \"end\":number} の形式で記述したもの。開始時間・終了時間の単位は秒で、精度はミリ秒まで。
-    """
+    """ """
 
     begin: float
-    """開始時間（ミリ秒）。小数点以下はミリ秒以下を表します。"""
+    """開始時間（ミリ秒）"""
 
     end: float
-    """終了時間（ミリ秒）。小数点以下はミリ秒以下を表します。"""
+    """終了時間（ミリ秒）"""
 
     type: str
-    """Range"""
+    """`Range` """
 
 
 @dataclass
@@ -154,18 +144,20 @@ class AdditionalData(DataClassJsonMixin):
 
 @dataclass
 class FullAnnotationAdditionalData(DataClassJsonMixin):
-    """ """
+    """
+    属性情報
+    """
 
-    additional_data_definition_id: Optional[str]
+    additional_data_definition_id: str
     """属性ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
-    additional_data_definition_name: Optional[InternationalizationMessage]
+    additional_data_definition_name: InternationalizationMessage
     """"""
 
-    type: Optional[AdditionalDataDefinitionType]
+    type: AdditionalDataDefinitionType
     """"""
 
-    value: Optional[AdditionalDataValue]
+    value: AdditionalDataValue
     """"""
 
 
@@ -174,7 +166,7 @@ class FullAnnotationDetail(DataClassJsonMixin):
     """ """
 
     annotation_id: str
-    """アノテーションID。[値の制約についてはこちら。](#section/API-Convention/APIID)<br> annotation_type が classification の場合は label_id と同じ値が格納されます。 """
+    """アノテーションID。[値の制約についてはこちら。](#section/API-Convention/APIID)  `annotation_type`が`classification`の場合は label_id と同じ値が格納されます。 """
 
     user_id: str
     """ユーザーID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
@@ -195,7 +187,7 @@ class FullAnnotationDetail(DataClassJsonMixin):
     """"""
 
     additional_data_list: List[FullAnnotationAdditionalData]
-    """"""
+    """属性情報。 """
 
 
 @dataclass
@@ -212,7 +204,7 @@ class FullAnnotation(DataClassJsonMixin):
     """"""
 
     task_phase_stage: int
-    """"""
+    """タスクのフェーズのステージ番号"""
 
     task_status: TaskStatus
     """"""
@@ -220,17 +212,17 @@ class FullAnnotation(DataClassJsonMixin):
     input_data_id: str
     """入力データID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
-    input_data_name: Optional[str]
-    """"""
+    input_data_name: str
+    """入力データ名"""
 
     details: List[FullAnnotationDetail]
-    """"""
+    """矩形、ポリゴン、全体アノテーションなど個々のアノテーションの配列"""
 
     updated_datetime: Optional[str]
-    """"""
+    """更新日時。アノテーションが一つもない場合（教師付作業が未着手のときなど）は、未指定。"""
 
     annotation_format_version: str
-    """アノテーションフォーマットのバージョンです。 アノテーションフォーマットとは、プロジェクト個別のアノテーション仕様ではなく、AnnoFabのアノテーション構造のことです。 したがって、アノテーション仕様を更新しても、このバージョンは変化しません。  バージョンの読み方と更新ルールは、業界慣習の[Semantic Versioning](https://semver.org/)にもとづきます。  JSONに出力されるアノテーションフォーマットのバージョンは、アノテーションZIPが作成される時点のものが使われます。 すなわち、`1.0.0`の時点のタスクで作成したアノテーションであっても、フォーマットが `1.0.1` に上がった次のZIP作成時では `1.0.1` となります。 バージョンを固定してZIPを残しておきたい場合は、プロジェクトが完了した時点でZIPをダウンロードして保管しておくか、またはプロジェクトを「停止中」にします。 """
+    """アノテーションフォーマットのバージョンです。 アノテーションフォーマットとは、プロジェクト個別のアノテーション仕様ではなく、Annofabのアノテーション構造のことです。 したがって、アノテーション仕様を更新しても、このバージョンは変化しません。  バージョンの読み方と更新ルールは、業界慣習の[Semantic Versioning](https://semver.org/)にもとづきます。  JSONに出力されるアノテーションフォーマットのバージョンは、アノテーションZIPが作成される時点のものが使われます。 すなわち、`1.0.0`の時点のタスクで作成したアノテーションであっても、フォーマットが `1.0.1` に上がった次のZIP作成時では `1.0.1` となります。 バージョンを固定してZIPを残しておきたい場合は、プロジェクトが完了した時点でZIPをダウンロードして保管しておくか、またはプロジェクトを「停止中」にします。 """
 
 
 @dataclass
@@ -255,7 +247,7 @@ class SimpleAnnotation(DataClassJsonMixin):
     """ """
 
     annotation_format_version: str
-    """アノテーションフォーマットのバージョンです。 アノテーションフォーマットとは、プロジェクト個別のアノテーション仕様ではなく、AnnoFabのアノテーション構造のことです。 したがって、アノテーション仕様を更新しても、このバージョンは変化しません。  バージョンの読み方と更新ルールは、業界慣習の[Semantic Versioning](https://semver.org/)にもとづきます。  JSONに出力されるアノテーションフォーマットのバージョンは、アノテーションZIPが作成される時点のものが使われます。 すなわち、`1.0.0`の時点のタスクで作成したアノテーションであっても、フォーマットが `1.0.1` に上がった次のZIP作成時では `1.0.1` となります。 バージョンを固定してZIPを残しておきたい場合は、プロジェクトが完了した時点でZIPをダウンロードして保管しておくか、またはプロジェクトを「停止中」にします。 """
+    """アノテーションフォーマットのバージョンです。 アノテーションフォーマットとは、プロジェクト個別のアノテーション仕様ではなく、Annofabのアノテーション構造のことです。 したがって、アノテーション仕様を更新しても、このバージョンは変化しません。  バージョンの読み方と更新ルールは、業界慣習の[Semantic Versioning](https://semver.org/)にもとづきます。  JSONに出力されるアノテーションフォーマットのバージョンは、アノテーションZIPが作成される時点のものが使われます。 すなわち、`1.0.0`の時点のタスクで作成したアノテーションであっても、フォーマットが `1.0.1` に上がった次のZIP作成時では `1.0.1` となります。 バージョンを固定してZIPを残しておきたい場合は、プロジェクトが完了した時点でZIPをダウンロードして保管しておくか、またはプロジェクトを「停止中」にします。 """
 
     project_id: str
     """プロジェクトID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
@@ -267,7 +259,7 @@ class SimpleAnnotation(DataClassJsonMixin):
     """"""
 
     task_phase_stage: int
-    """"""
+    """タスクのフェーズのステージ番号"""
 
     task_status: TaskStatus
     """"""
@@ -287,10 +279,12 @@ class SimpleAnnotation(DataClassJsonMixin):
 
 @dataclass
 class SingleAnnotationDetail(DataClassJsonMixin):
-    """ """
+    """
+    アノテーション情報
+    """
 
     annotation_id: str
-    """アノテーションID。[値の制約についてはこちら。](#section/API-Convention/APIID)<br> annotation_type が classification の場合は label_id と同じ値が格納されます。 """
+    """アノテーションID。[値の制約についてはこちら。](#section/API-Convention/APIID)  `annotation_type`が`classification`の場合は label_id と同じ値が格納されます。 """
 
     account_id: str
     """アカウントID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
@@ -311,13 +305,13 @@ class SingleAnnotationDetail(DataClassJsonMixin):
     """data_holding_typeがouterの場合のみ存在し、データへの一時URLが格納される"""
 
     additional_data_list: List[AdditionalData]
-    """"""
+    """属性情報。  アノテーション属性の種類（`additional_data_definition`の`type`）によって、属性値を格納するプロパティは変わります。  | 属性の種類 | `additional_data_definition`の`type` | 属性値を格納するプロパティ                    | |------------|-------------------------|----------------------| | ON/OFF | flag       | flag                                          | | 整数 | integer    | integer                                       | | 自由記述（1行）| text       | comment                                       | | 自由記述（複数行）| comment    | comment                                       | | トラッキングID  | tracking | comment                                       | | アノテーションリンク    | link   | comment                                       | | 排他選択（ラジオボタン）  |choice   | choice                                        | | 排他選択（ドロップダウン） | select    | choice                                        | """
 
     created_datetime: str
-    """"""
+    """作成日時"""
 
     updated_datetime: str
-    """"""
+    """更新日時"""
 
 
 @dataclass
@@ -337,7 +331,7 @@ class SingleAnnotation(DataClassJsonMixin):
     """"""
 
     updated_datetime: str
-    """"""
+    """更新日時"""
 
 
 @dataclass
@@ -345,7 +339,7 @@ class AnnotationDetail(DataClassJsonMixin):
     """ """
 
     annotation_id: str
-    """アノテーションID。[値の制約についてはこちら。](#section/API-Convention/APIID)<br> annotation_type が classification の場合は label_id と同じ値が格納されます。 """
+    """アノテーションID。[値の制約についてはこちら。](#section/API-Convention/APIID)  `annotation_type`が`classification`の場合は label_id と同じ値が格納されます。 """
 
     account_id: str
     """アカウントID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
@@ -372,13 +366,13 @@ class AnnotationDetail(DataClassJsonMixin):
     """外部ファイルに保存されたアノテーションの認証済み一時URL。`data_holding_type`が`inner`の場合、または[putAnnotation](#operation/putAnnotation) APIのリクエストボディに渡す場合は未指定です。"""
 
     additional_data_list: List[AdditionalData]
-    """各要素は、 [アノテーション仕様](#operation/getAnnotationSpecs)で定義された属性（`additional_data_definitions`内）のいずれかの要素と対応づけます。 各要素は、どの属性なのかを表す`additional_data_definition_id`と値が必要です。値は、属性の種類に対応するキーに格納します（下表）。  <table> <tr><th>アノテーション属性の種類<br>（<code>additional_data_definition</code>の<code>type</code>）</th><th>属性の値を格納するキー</th><th>データ型</th></tr> <tr><td><code>text</code>, <code>comment</code> または <code>tracking</code></td><td><code>comment</code></td><td>string</td></tr> <tr><td><code>flag<c/ode></td><td><code>flag</code></td><td>boolean</td></tr> <tr><td><code>integer</code></td><td><code>integer</code></td><td>integer</td></tr> <tr><td><code>choice</code> または <code>select</code></td><td><code>choice</code></td><td>string（選択肢ID）</td></tr> <tr><td><code>link</code></td><td><code>comment</code></td><td>string（アノテーションID）</td></tr> </table> """
+    """属性情報。  アノテーション属性の種類（`additional_data_definition`の`type`）によって、属性値を格納するプロパティは変わります。  | 属性の種類 | `additional_data_definition`の`type` | 属性値を格納するプロパティ                    | |------------|-------------------------|----------------------| | ON/OFF | flag       | flag                                          | | 整数 | integer    | integer                                       | | 自由記述（1行）| text       | comment                                       | | 自由記述（複数行）| comment    | comment                                       | | トラッキングID  | tracking | comment                                       | | アノテーションリンク    | link   | comment                                       | | 排他選択（ラジオボタン）  |choice   | choice                                        | | 排他選択（ドロップダウン） | select    | choice                                        | """
 
     created_datetime: Optional[str]
-    """"""
+    """作成日時"""
 
     updated_datetime: Optional[str]
-    """"""
+    """更新日時"""
 
 
 @dataclass
@@ -398,4 +392,4 @@ class Annotation(DataClassJsonMixin):
     """矩形、ポリゴン、全体アノテーションなど個々のアノテーションの配列。"""
 
     updated_datetime: Optional[str]
-    """新規作成時は未指定、更新時は必須（更新前の日時） """
+    """更新日時"""
