@@ -26,7 +26,9 @@ from annofabapi.models import (
 
 @dataclass
 class ProjectSummary(DataClassJsonMixin):
-    """ """
+    """
+    プロジェクトのサマリー情報
+    """
 
     last_tasks_updated_datetime: Optional[str]
     """タスクの最終更新日時"""
@@ -34,7 +36,9 @@ class ProjectSummary(DataClassJsonMixin):
 
 @dataclass
 class ProjectConfiguration(DataClassJsonMixin):
-    """ """
+    """
+    プロジェクトの設定情報
+    """
 
     number_of_inspections: Optional[int]
     """検査回数。 * 0回：教師付け -> 受入 * 1回：教師付け -> 検査 -> 受入 * n回(n >= 2)：教師付け -> 検査1 -> ... -> 検査n -> 受入 """
@@ -49,10 +53,10 @@ class ProjectConfiguration(DataClassJsonMixin):
     """"""
 
     max_tasks_per_member: Optional[int]
-    """保留中のタスクを除き、1人（オーナー以外）に割り当てられるタスク数上限。未指定の場合は10件として扱う。"""
+    """保留中のタスクを除き、1人（オーナー以外）に割り当てられるタスク数の上限。 """
 
     max_tasks_per_member_including_hold: Optional[int]
-    """保留中のタスクを含めて、1人（オーナー以外）に割り当てられるタスク数上限。未指定の場合は20件として扱う。"""
+    """保留中のタスクを含めて、1人（オーナー以外）に割り当てられるタスク数上限の保留分。 割り当て時の上限チェックは、max_tasks_per_memberとこの数字の合計で行われます。  例えばmax_tasks_per_memberが10、max_tasks_per_member_including_holdが20の場合、保留中を含むタスク数の割り当て上限は30になります。 """
 
     input_data_set_id_list: Optional[List[str]]
     """このフィールドは内部用でまだ何も意味を成しません。今は空配列を指定してください。"""
@@ -61,10 +65,10 @@ class ProjectConfiguration(DataClassJsonMixin):
     """入力データ画像の長辺の最大値（未指定時は4096px）。  画像をアップロードすると、長辺がこの値になるように画像が自動で圧縮されます。 アノテーションの座標は、もとの解像度の画像でつけたものに復元されます。  大きな数値を設定すると入力データ画像のサイズが大きくなり、生産性低下やブラウザで画像を表示できない懸念があります。注意して設定してください。 """
 
     sampling_inspection_rate: Optional[int]
-    """抜取検査率。0-100のパーセント値で指定し、未指定の場合は100%として扱う。"""
+    """抜取検査率[%]。未指定の場合は100%として扱う。"""
 
     sampling_acceptance_rate: Optional[int]
-    """抜取受入率。0-100のパーセント値で指定し、未指定の場合は100%として扱う。"""
+    """抜取受入率[%]。未指定の場合は100%として扱う。"""
 
     private_storage_aws_iam_role_arn: Optional[str]
     """AWS IAMロール。ビジネスプランでのS3プライベートストレージの認可で使います。 [S3プライベートストレージの認可の設定についてはこちら](/docs/faq/#m0b240)をご覧ください。 """
@@ -82,7 +86,7 @@ class ProjectConfiguration(DataClassJsonMixin):
     """標準アノテーションエディタのバージョン。  * `stable`     * 安定版。通常はこちらを利用してください。 * `preview`     * 最新版。新機能やUI変更の先行リリース版。  プロジェクト更新時に未指定の場合は `stable` が指定されたものとみなします。 """
 
     use_beginner_navigation: Optional[bool]
-    """true の場合、プロジェクトの画面でナビゲーションUIを表示します（ログインユーザーがプロジェクトオーナーの場合のみ）。  未指定の場合、 false が指定されたものとして扱います。 """
+    """true の場合、プロジェクトの画面でナビゲーションUIを表示します（ログインユーザーがプロジェクトオーナーの場合のみ）。 """
 
 
 @dataclass
@@ -111,10 +115,10 @@ class Project(DataClassJsonMixin):
     """"""
 
     created_datetime: str
-    """"""
+    """作成日時"""
 
     updated_datetime: str
-    """"""
+    """更新日時"""
 
     summary: ProjectSummary
     """"""
