@@ -31,13 +31,13 @@ class TaskHistory(DataClassJsonMixin):
     """タスクID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     task_history_id: str
-    """"""
+    """タスク履歴ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     started_datetime: Optional[str]
-    """"""
+    """開始日時"""
 
     ended_datetime: Optional[str]
-    """"""
+    """終了日時"""
 
     accumulated_labor_time_milliseconds: str
     """累計実作業時間（ISO 8601 duration）"""
@@ -46,7 +46,7 @@ class TaskHistory(DataClassJsonMixin):
     """"""
 
     phase_stage: int
-    """"""
+    """タスクのフェーズのステージ番号"""
 
     account_id: Optional[str]
     """アカウントID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
@@ -85,7 +85,7 @@ class Task(DataClassJsonMixin):
     """"""
 
     phase_stage: int
-    """"""
+    """タスクのフェーズのステージ番号"""
 
     status: TaskStatus
     """"""
@@ -106,13 +106,13 @@ class Task(DataClassJsonMixin):
     """このタスクが差戻しされた回数（すべてのフェーズでの差戻し回数の合計  このフィールドは、どのフェーズで何回差戻されたかを区別できないため、廃止予定です。 `histories_by_phase` で各フェーズの回数を計算することで、差戻し回数が分かります。  例）`acceptance`フェーズが3回ある場合、`acceptance`フェーズで2回差し戻しされたことになります。 """
 
     started_datetime: Optional[str]
-    """"""
+    """現在のフェーズが開始された日時"""
 
     updated_datetime: str
-    """"""
+    """更新日時"""
 
     sampling: Optional[str]
-    """* `inspection_skipped` - このタスクが抜取検査の対象外となり、検査フェーズをスキップしたことを表す。 * `inspection_stages_skipped` - このタスクが抜取検査の対象外となり、検査フェーズのステージを一部スキップしたことを表す。 * `acceptance_skipped` - このタスクが抜取検査の対象外となり、受入フェーズをスキップしたことを表す。 * `inspection_and_acceptance_skipped` - このタスクが抜取検査の対象外となり、検査・受入フェーズをスキップしたことを表す  未指定時はこのタスクが抜取検査の対象となったことを表す。(通常のワークフローを通過する) """
+    """検査抜取検査/抜取受入によって、どのフェーズがスキップされたか  * `inspection_skipped` - 抜取検査の対象外となり、検査フェーズがスキップされた * `inspection_stages_skipped` - 抜取検査の対象外となり、検査フェーズのステージの一部がスキップされた * `acceptance_skipped` - 抜取受入の対象外となり、受入フェーズがスキップされた * `inspection_and_acceptance_skipped` - 抜取検査・抜取受入の対象外となり、検査・受入フェーズがスキップされた  未指定ならば、どのフェーズもスキップされていません。 """
 
     metadata: Optional[Dict[str, Any]]
     """ユーザーが自由に登録できるkey-value型のメタデータです。 keyにはメタデータ名、valueには値を指定してください。  keyに指定できる文字種は次の通りです。  * 半角英数字 * `_` (アンダースコア) * `-` (ハイフン)  valueに指定できる値は次の通りです。  * 文字列 * 数値 * 真偽値 """
